@@ -1,14 +1,14 @@
 
 # -*- codeing = utf-8 -*-
 # @File：hhDouban.py
-# @Ver：1.5.1
+# @Ver：1.6.0
 # @Author：立树
-# @Time：2021/07/07 01:54
+# @Time：2021/07/07 16:28
 # @IDE：PyCharm
 
 """
 更新：
-- 优化 getMovieDetail 关闭调试
+- 优化 getMoviePicList 豆瓣电影图片列表抓取
 """
 
 import re
@@ -294,7 +294,10 @@ class hhDouban(object):
             return {}
 
         # 返回的数据
-        movie = {"id": id}
+        movie = {
+            "id": id,
+            "url": f"https://movie.douban.com/subject/{id}/"
+        }
 
         try:
             # 发起请求
@@ -311,14 +314,18 @@ class hhDouban(object):
             html = BeautifulSoup(page,"html.parser")
 
             names = html.select("#content > h1 > span")[0].text
-            name = html.select("#mainpic > a > img")[0].attrs["alt"]
-            alias = names.replace(name,"").strip()
+            alias = html.select("#mainpic > a > img")[0].attrs["alt"]
+            name = names.replace(alias,"").strip()
             movie["name"] = name
             movie["alias"] = alias
 
             movie["poster"] = html.select("#mainpic > a > img")[0].attrs["src"]
-            movie["score"] = html.select("#interest_sectl .rating_num")[0].text
-            movie["rating_num"] = html.select("#interest_sectl .rating_people span")[0].text
+
+            # 评分
+            if len(html.select("#interest_sectl .rating_num")):
+                movie["score"] = html.select("#interest_sectl .rating_num")[0].text
+            if html.select("#interest_sectl .rating_people span"):
+                movie["rating_num"] = html.select("#interest_sectl .rating_people span")[0].text
 
             # movie["director"] = "、".join(list(map(lambda item:item.text,html.select("#info > span:nth-child(1) a"))))
             # movie["writer"] = "、".join(list(map(lambda item:item.text,html.select("#info > span:nth-child(3) a"))))
@@ -339,7 +346,7 @@ class hhDouban(object):
                     movie["type"] = item.split(": ")[1].replace(" / ","、")
                     continue
                 if "官方网站" in item:
-                    movie["type"] = item.split(": ")[1]
+                    movie["website"] = item.split(": ")[1]
                     continue
                 if "制片国家/地区" in item:
                     movie["area"] = item.split(": ")[1].replace(" / ","、")
@@ -368,7 +375,7 @@ class hhDouban(object):
 
             movie["descp"] = movie["descp"].replace("\u3000","").replace("\r","<br>").strip()
             movie["descp"] = movie["descp"].replace("\n","<br>")
-            movie["descp"] = re.sub("\s","",movie["descp"])
+            movie["descp"] = re.sub("\s{2,}","",movie["descp"])
 
         except Exception as err:
             print(f"hhframe.hhDouban.getMovieDetail() Error - {err}")
@@ -392,7 +399,7 @@ class hhDouban(object):
             for actor in html.select("#celebrities .list-wrapper:nth-child(2) li"):
                 actors.append({
                     "name": actor.select(".info .name a.name")[0].text,
-                    "role": re.findall("\([饰|配] (.*)\)", actor.select(".info .role")[0].text)
+                    "role": "".join(re.findall("\([饰|配] (.*)\)", actor.select(".info .role")[0].text))
                 })
             movie["actor2"] = actors
 
@@ -400,3 +407,104 @@ class hhDouban(object):
         except Exception as err:
             print(f"hhframe.hhDouban.getMovieDetail() Error - {err}")
             return {}
+
+    # 豆瓣电影图片列表抓取
+    def getMoviePicList(self,id="",page=1,type="",subtype="",sort="like"):
+        # type
+        # S 剧照（Stage Photo）
+        # R 海报（？？？）
+        # W 壁纸（Wallpaper）
+        # subtype
+        # S a 全部（all）
+        # S o 官方剧照（official）
+        # S c 截图（）
+        # S w 工作照（work）
+        # S n 新闻图片（news）
+        # S f 粉丝图片（fans）
+        # R a 全部海报（all）
+        # R o 正式海报（official）
+        # R p 预告海报（preview）
+        # R t 其他海报（）
+        # R o 正式海报（official）
+        # R p 预告海报（preview）
+        # W a 全部壁纸（all）
+        # W 1920x1080
+        # sort
+        # - like 喜欢
+        # - size 尺寸
+        # - time 时间
+
+        # 参数判断
+        if id == "":
+            print("hhframe.hhDouban.getStarPhoto() Error - 请补全参数（id）")
+            return {}
+
+        # 参数检测
+        Types = ["S","R","W"]
+        Subtypes = {
+            "S": ["a","o","c","w","n","f"],
+            "R": ["a","o","p","t"],
+            "W": ["a","1920x1200","1920x1080","1600x1280","1600x1200","1600x1050","1600x1000","1280x1024","1280x960","1280x800"]
+        }
+        Sorts = ["like","size","time"]
+
+        type = type if type in Types else Types[0]
+        subtype = subtype if subtype in Subtypes[type] else Subtypes[type][0]
+        sort = sort if sort in Sorts else Sorts[0]
+        start = (int(page)-1)*30
+
+        if type=="W":
+            url = f"https://movie.douban.com/subject/{id}/photos?type={type}&size={subtype}&subtype=a&start={start}&sortby={sort}"
+        else:
+            url = f"https://movie.douban.com/subject/{id}/photos?type={type}&size=a&subtype={subtype}&start={start}&sortby={sort}"
+
+        try:
+            # 发起请求
+            contt = hhGet(url)
+
+            # 调试
+            # import os
+            # from src.hhframe import hhUrl,hhOs
+            # file = "./demo_douban_star_photo_list.html"
+            # if not os.path.exists(file):
+            #     hhUrl.hhDownload(url,file)
+            # contt = hhOs.hhOpenFile(file,"r")
+
+            html = BeautifulSoup(contt,"html.parser")
+
+            MoviePic = {
+                "id": id,
+                "name": re.sub("的(剧照|海报|壁纸)","",html.select("#content h1")[0].text),
+                "sum": 0,
+                "page": page,
+                "size": 30,
+                "pics": [],
+                "items": []
+            }
+
+            list = html.select(".article .poster-col3 li")
+            for item in list:
+                url = item.select(".cover a")[0].attrs["href"]
+                img = item.select(".cover img")[0].attrs["src"]
+                size = item.select(".prop")[0].text.strip()
+                reply = item.select(".name a")[0].text if len(item.select(".name a")) else ""
+                title = item.select(".name")[0].text.replace(reply, "").strip()
+                MoviePic["items"].append({
+                    "url": url,
+                    "img": img,
+                    "width": int(size.split("x")[0]),
+                    "height": int(size.split("x")[1]),
+                    "title": title
+                })
+                MoviePic["pics"].append(img)
+
+            # 图片总数
+            if len(html.select(".paginator")):
+                MoviePic["sum"] = int(re.findall("(\d+)",html.select(".paginator .count")[0].text)[0])
+            else:
+                MoviePic["sum"] = len(list)
+
+            return MoviePic
+        except Exception as err:
+            print(f"hhframe.hhDouban.getStarPhoto() Error - {err}")
+            return {}
